@@ -3,7 +3,7 @@
  * Support for gnat/rtems interrupts and exception handling.
  * Jiri Gaisler, ESA/ESTEC, 17-02-1999.
  *
- *  $Id: gnatsupp.c,v 1.2 2006/01/09 10:36:06 ralf Exp $
+ *  $Id$
  */
 
 void __gnat_install_handler_common (int t1, int t2);
@@ -14,7 +14,7 @@ void __gnat_install_handler_common (int t1, int t2);
  */
 
 void
-__gnat_install_handler ()
+__gnat_install_handler (void)
 {
   __gnat_install_handler_common (0x18, 0x12);
 }
