@@ -3,8 +3,8 @@
  *
  *  This driver hook performs bus scanning.
  *
- *  COPYRIGHT (c) 2008.
- *  Gaisler Research
+ *  COPYRIGHT (c) 2011.
+ *  Aeroflex Gaisler
  *
  *  The license and distribution terms for this file may be
  *  found in the file LICENSE in this distribution or at
@@ -12,6 +12,7 @@
  *
  *  $Id$
  */
+
 #include <bsp.h>
 #include <ambapp.h>
 
@@ -32,7 +33,7 @@ struct ambapp_bus ambapp_plb;
 extern void gptimer_register_drv (void);
 extern void apbuart_cons_register_drv(void);
 /* All drivers included by BSP, this is overridden by the user by including
- * the devmgr_confdefs.h. By default the Timer and UART driver is included.
+ * the drvmgr_confdefs.h. By default the Timer and UART driver are included.
  */
 struct drvmgr_drv_reg_func drvmgr_drivers[] __attribute__((weak)) =
 {
@@ -55,7 +56,7 @@ struct drvmgr_bus_res grlib_drv_resources __attribute__((weak)) =
 };
 
 /* GRLIB AMBA bus configuration (the LEON3 root bus configuration) */
-struct grlib_config grlib_bus_config = 
+struct grlib_config grlib_bus_config =
 {
   &ambapp_plb,              /* AMBAPP bus setup */
   &grlib_drv_resources,     /* Driver configuration */
@@ -66,14 +67,7 @@ struct grlib_config grlib_bus_config =
 extern void leon3_ext_irq_init(void);
 
 /* Pointers to Interrupt Controller configuration registers */
-volatile LEON3_IrqCtrl_Regs_Map *LEON3_IrqCtrl_Regs;
-
-/* AMBA PP find routines */
-int find_matching_adev(struct ambapp_dev *dev, int index, void *arg)
-{
-	*(struct ambapp_dev **)arg = dev;
-	return 1; /* Satisfied with first matching device, stop search */
-}
+volatile struct irqmp_regs *LEON3_IrqCtrl_Regs;
 
 /*
  *  amba_initialize
@@ -87,20 +81,21 @@ int find_matching_adev(struct ambapp_dev *dev, int index, void *arg)
 
 void amba_initialize(void)
 {
-  int i, icsel;
+  int icsel;
   struct ambapp_dev *adev;
 
-  /* Scan AMBA Plug&Play information, assuming malloc() works.
-   * The routine builds a PnP tree into ambapp_plb.root in RAM, so after this
-   * we never access PnP information in Hardware any more.
+  /* Scan AMBA Plug&Play read-only information. The routine builds a PnP
+   * tree into ambapp_plb in RAM, after this we never access the PnP
+   * information in hardware directly any more.
    * Since on Processor Local Bus (PLB) memory mapping is 1:1
    */
   ambapp_scan(&ambapp_plb, LEON3_IO_AREA, NULL, NULL);
 
   /* Find LEON3 Interrupt controller */
-  i = ambapp_for_each(&ambapp_plb, (OPTIONS_ALL|OPTIONS_APB_SLVS), 
-              VENDOR_GAISLER, GAISLER_IRQMP, find_matching_adev, &adev);
-  if ( i <= 0 ) {
+  adev = (void *)ambapp_for_each(&ambapp_plb, (OPTIONS_ALL|OPTIONS_APB_SLVS),
+                                 VENDOR_GAISLER, GAISLER_IRQMP,
+                                 ambapp_find_by_idx, NULL);
+  if (adev == NULL) {
     /* PANIC IRQ controller not found!
      *
      *  What else can we do but stop ...
@@ -108,9 +103,8 @@ void amba_initialize(void)
     asm volatile( "mov 1, %g1; ta 0x0" );
   }
 
-  LEON3_IrqCtrl_Regs = (volatile LEON3_IrqCtrl_Regs_Map *)
-                       ((struct ambapp_apb_info *)adev->devinfo)->start;
-  if ( (LEON3_IrqCtrl_Regs->ampctrl >> 28) > 0 ) {
+  LEON3_IrqCtrl_Regs = (volatile struct irqmp_regs *)DEV_TO_APB(adev)->start;
+  if ((LEON3_IrqCtrl_Regs->ampctrl >> 28) > 0) {
     /* IRQ Controller has support for multiple IRQ Controllers, each
      * CPU can be routed to different Controllers, we find out which
      * controller by looking at the IRQCTRL Select Register for this CPU.
@@ -133,21 +127,18 @@ void amba_initialize(void)
    * instead we use the small-footprint drivers.
    */
 #ifndef RTEMS_DRVMGR_STARTUP
-
   /* find GP Timer */
-  i = ambapp_for_each(&ambapp_plb, (OPTIONS_ALL|OPTIONS_APB_SLVS), 
-              VENDOR_GAISLER, GAISLER_GPTIMER, find_matching_adev, &adev);
-  if ( i > 0 ){
-    LEON3_Timer_Regs = (volatile LEON3_Timer_Regs_Map *)
-                        ((struct ambapp_apb_info *)adev->devinfo)->start;
+  adev = (void *)ambapp_for_each(&ambapp_plb, (OPTIONS_ALL|OPTIONS_APB_SLVS),
+                                 VENDOR_GAISLER, GAISLER_GPTIMER,
+                                 ambapp_find_by_idx, NULL);
+  if (adev) {
+    LEON3_Timer_Regs = (volatile struct gptimer_regs *)DEV_TO_APB(adev)->start;
 
     /* Register AMBA Bus Frequency */
-    ambapp_freq_init(&ambapp_plb, adev, 
+    ambapp_freq_init(&ambapp_plb, adev,
                      (LEON3_Timer_Regs->scaler_reload + 1) * 1000000);
   }
-
 #else
-
   /* Register Root bus, Use GRLIB AMBA PnP bus as root bus for LEON3 */
   ambapp_grlib_root_register(&grlib_bus_config);
 #endif
