@@ -112,7 +112,7 @@ struct gr_rasta_spw_router_priv {
 
 	/* GR-RASTA-SPW-ROUTER */
 	struct gr_rasta_spw_router_ver	*version;
-	LEON3_IrqCtrl_Regs_Map	*irq;
+	struct irqmp_regs	*irq;
 	struct grpci2_regs	*grpci2;
 	struct drvmgr_map_entry	bus_maps_up[2];
 	struct drvmgr_map_entry	bus_maps_down[2];
@@ -241,14 +241,6 @@ void gr_rasta_spw_router_isr(void *arg)
 	DBG("RASTA-SPW_ROUTER-IRQ: 0x%x\n", tmp);
 }
 
-/* AMBA PP find routines */
-int gr_rasta_spw_router_dev_find(struct ambapp_dev *dev, int index, void *arg)
-{
-	/* Found IRQ/GRPCI2 controller, stop */
-	*(struct ambapp_dev **)arg = dev;
-	return 1;
-}
-
 int gr_rasta_spw_router_hw_init(struct gr_rasta_spw_router_priv *priv)
 {
 	int i;
@@ -324,12 +316,14 @@ int gr_rasta_spw_router_hw_init(struct gr_rasta_spw_router_priv *priv)
 	ambapp_freq_init(&priv->abus, NULL, priv->version->amba_freq_hz);
 
 	/* Find IRQ controller, Clear all current IRQs */
-	tmp = NULL;
-	status = ambapp_for_each(&priv->abus, (OPTIONS_ALL|OPTIONS_APB_SLVS), VENDOR_GAISLER, GAISLER_IRQMP, gr_rasta_spw_router_dev_find, &tmp);
-	if ( (status != 1) || !tmp ) {
+	tmp = ambapp_for_each(&priv->abus,
+				(OPTIONS_ALL|OPTIONS_APB_SLVS),
+				VENDOR_GAISLER, GAISLER_IRQMP,
+				ambapp_find_by_idx, NULL);
+	if ( !tmp ) {
 		return -4;
 	}
-	priv->irq = (LEON3_IrqCtrl_Regs_Map *)(((struct ambapp_apb_info *)tmp->devinfo)->start);
+	priv->irq = (struct irqmp_regs *)DEV_TO_APB(tmp)->start;
 	/* Set up GR-RASTA-SPW-ROUTER irq controller */
 	priv->irq->mask[0] = 0;
 	priv->irq->iclear = 0xffff;
@@ -342,9 +336,11 @@ int gr_rasta_spw_router_hw_init(struct gr_rasta_spw_router_priv *priv)
 	priv->bus_maps_down[1].size = 0;
 
 	/* Find GRPCI2 controller AHB Slave interface */
-	tmp = NULL;
-	status = ambapp_for_each(&priv->abus, (OPTIONS_ALL|OPTIONS_AHB_SLVS), VENDOR_GAISLER, GAISLER_GRPCI2, gr_rasta_spw_router_dev_find, &tmp);
-	if ( (status != 1) || !tmp ) {
+	tmp = (void *)ambapp_for_each(&priv->abus,
+					(OPTIONS_ALL|OPTIONS_AHB_SLVS),
+					VENDOR_GAISLER, GAISLER_GRPCI2,
+					ambapp_find_by_idx, NULL);
+	if ( !tmp ) {
 		return -5;
 	}
 	ahb = (struct ambapp_ahb_info *)tmp->devinfo;
@@ -356,9 +352,11 @@ int gr_rasta_spw_router_hw_init(struct gr_rasta_spw_router_priv *priv)
 	priv->bus_maps_up[1].size = 0;
 
 	/* Find GRPCI2 controller APB Slave interface */
-	tmp = NULL;
-	status = ambapp_for_each(&priv->abus, (OPTIONS_ALL|OPTIONS_APB_SLVS), VENDOR_GAISLER, GAISLER_GRPCI2, gr_rasta_spw_router_dev_find, &tmp);
-	if ( (status != 1) || !tmp ) {
+	tmp = (void *)ambapp_for_each(&priv->abus,
+					(OPTIONS_ALL|OPTIONS_APB_SLVS),
+					VENDOR_GAISLER, GAISLER_GRPCI2,
+					ambapp_find_by_idx, NULL);
+	if ( !tmp ) {
 		return -6;
 	}
 	priv->grpci2 = (struct grpci2_regs *)
