@@ -6,7 +6,7 @@
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: cre_por.c,v 1.1 2007/04/17 20:32:12 joel Exp $
+ *  $Id$
  */
 
 #if HAVE_CONFIG_H
@@ -22,8 +22,8 @@
  */
 
 ER cre_por(
-  ID      porid,
-  T_CPOR *pk_cpor
+  ID      porid __attribute__((unused)),
+  T_CPOR *pk_cpor __attribute__((unused))
 )
 {
   return E_OK;
