@@ -6,7 +6,7 @@
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: pget_blf.c,v 1.1 2007/04/17 20:32:12 joel Exp $
+ *  $Id$
  */
 
 #if HAVE_CONFIG_H
@@ -22,8 +22,8 @@
  */
 
 ER pget_blf(
-  VP *p_blf,
-  ID  mpfid
+  VP *p_blf __attribute__((unused)),
+  ID  mpfid __attribute__((unused))
 )
 {
   return E_OK;
