@@ -1,14 +1,14 @@
 /*
  *  open_dev_console - open /dev/console
  *
- *  COPYRIGHT (c) 1989-2007.
+ *  COPYRIGHT (c) 1989-2009.
  *  On-Line Applications Research Corporation (OAR).
  *
  *  The license and distribution terms for this file may be
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: open_dev_console.c,v 1.1 2007/06/20 22:20:32 joel Exp $
+ *  $Id$
  */
 
 #if HAVE_CONFIG_H
@@ -20,13 +20,13 @@
 #include <fcntl.h>
 
 /*
- *  This is a replaceable stub
+ *  This is a replaceable stub which opens the console, if present.
  */
-
 void open_dev_console(void)
 {
-  int stdin_fd, stdout_fd, stderr_fd;
-  int error_code = 'S' << 24 | 'T' << 16 | 'D' << 8;
+  int      stdin_fd;
+  int      stdout_fd;
+  int      stderr_fd;
 
   /*
    * Attempt to open /dev/console.
@@ -36,16 +36,16 @@ void open_dev_console(void)
      * There may not be a console driver so this is OK.
      */
     return;
-  } 
+  }
 
   /*
    *  But if we find /dev/console once, we better find it twice more
    *  or something is REALLY wrong.
    */
   if ((stdout_fd = open("/dev/console", O_WRONLY, 0)) == -1)
-    rtems_fatal_error_occurred( error_code | '1' );
+    rtems_fatal_error_occurred( 0x55544431 );  /* error STD1 */
 
   if ((stderr_fd = open("/dev/console", O_WRONLY, 0)) == -1)
-    rtems_fatal_error_occurred( error_code | '2' );
+    rtems_fatal_error_occurred( 0x55544432 );  /* error STD2 */
 }
 
