@@ -1,14 +1,14 @@
 /*
  *  RWLock Manager -- Translate SuperCore Status
  *
- *  COPYRIGHT (c) 1989-2006.
+ *  COPYRIGHT (c) 1989-2007.
  *  On-Line Applications Research Corporation (OAR).
  *
  *  The license and distribution terms for this file may be
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: prwlocktranslatereturncode.c,v 1.1 2006/11/15 14:08:49 joel Exp $
+ *  $Id$
  */
 
 #if HAVE_CONFIG_H
@@ -32,8 +32,7 @@
  *
  */
 
-/* XXX fix me */
-static int _POSIX_RWLock_Return_codes[] = {
+static int _POSIX_RWLock_Return_codes[CORE_RWLOCK_STATUS_LAST + 1] = {
   0,                        /* CORE_RWLOCK_SUCCESSFUL */
   EINVAL,                   /* CORE_RWLOCK_DELETED */
   EBUSY,                    /* CORE_RWLOCK_UNAVAILABLE */
@@ -45,7 +44,12 @@ int _POSIX_RWLock_Translate_core_RWLock_return_code(
   CORE_RWLock_Status  the_rwlock_status
 )
 {
-  if ( the_rwlock_status <= CORE_RWLOCK_STATUS_LAST )
-    return _POSIX_RWLock_Return_codes[the_rwlock_status];
-  return POSIX_BOTTOM_REACHED();
+  /*
+   *  Internal consistency check for bad status from SuperCore
+   */
+  #if defined(RTEMS_DEBUG)
+    if ( the_rwlock_status > CORE_RWLOCK_STATUS_LAST )
+      return EINVAL;
+  #endif
+  return _POSIX_RWLock_Return_codes[the_rwlock_status];
 }
