@@ -9,7 +9,7 @@
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: intrbody.c,v 1.6 2005/01/18 09:03:43 ralf Exp $
+ *  $Id$
  */
 
 #if HAVE_CONFIG_H
@@ -68,7 +68,7 @@ void rtems_interrupt_flash(
 
 #undef rtems_interrupt_is_in_progress
 
-boolean rtems_interrupt_is_in_progress( void )
+bool rtems_interrupt_is_in_progress( void )
 {
   return _ISR_Is_in_progress();
 }
