@@ -1,15 +1,14 @@
 /*
  *  Extension Manager
  *
- *
- *  COPYRIGHT (c) 1989-2002.
+ *  COPYRIGHT (c) 1989-2008.
  *  On-Line Applications Research Corporation (OAR).
  *
  *  The license and distribution terms for this file may be
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: extension.c,v 1.18 2005/01/28 02:04:21 ralf Exp $
+ *  $Id$
  */
 
 #if HAVE_CONFIG_H
@@ -17,6 +16,7 @@
 #endif
 
 #include <rtems/system.h>
+#include <rtems/config.h>
 #include <rtems/rtems/support.h>
 #include <rtems/score/object.h>
 #include <rtems/score/thread.h>
@@ -28,27 +28,24 @@
  *
  *  This routine initializes all extension manager related data structures.
  *
- *  Input parameters:
- *    maximum_extensions - number of extensions to initialize
+ *  Input parameters:   NONE
  *
  *  Output parameters:  NONE
  */
 
-void _Extension_Manager_initialization(
-  uint32_t   maximum_extensions
-)
+void _Extension_Manager_initialization(void)
 {
   _Objects_Initialize_information(
     &_Extension_Information,
     OBJECTS_CLASSIC_API,                 /* object API */
     OBJECTS_RTEMS_EXTENSIONS,
-    maximum_extensions,
+    Configuration.maximum_extensions,
     sizeof( Extension_Control ),
-    FALSE,                     /* TRUE if the name is a string */
+    false,                     /* true if the name is a string */
     RTEMS_MAXIMUM_NAME_LENGTH  /* maximum length of an object name */
 #if defined(RTEMS_MULTIPROCESSING)
     ,
-    FALSE,                     /* TRUE if this is a global object class */
+    false,                     /* true if this is a global object class */
     NULL                       /* Proxy extraction support callout */
 #endif
   );
