@@ -13,7 +13,7 @@
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: delay.c,v 1.9 2003/09/04 18:53:30 joel Exp $
+ *  $Id$
  */
 
 #include "system.h"
@@ -26,5 +26,6 @@ rtems_timer_service_routine Delayed_send_event(
   rtems_status_code status;
 
   status = rtems_event_send( Task_id[ 1 ], RTEMS_EVENT_16 );
-  directive_failed_with_level( status, "rtems_event_send", 1 );
+  if ( status ) printk( "Delayed_send_event failed %d\n", status );
+  // directive_failed_with_level( status, "rtems_event_send", 1 );
 }
