@@ -15,10 +15,11 @@
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: asr.c,v 1.8 2003/09/04 18:53:48 joel Exp $
+ *  $Id$
  */
 
 #include "system.h"
+#include "tmacros.h"
 
 rtems_asr Process_asr(
   rtems_signal_set the_signal_set
@@ -26,7 +27,7 @@ rtems_asr Process_asr(
 {
   rtems_status_code status;
 
-  printf( "ASR - ENTRY - signal => %08x\n", the_signal_set );
+  printf( "ASR - ENTRY - signal => %08" PRIxrtems_signal_set "\n", the_signal_set );
   switch( the_signal_set ) {
     case RTEMS_SIGNAL_16:
     case RTEMS_SIGNAL_17:
@@ -35,6 +36,7 @@ rtems_asr Process_asr(
     case RTEMS_SIGNAL_0:
     case RTEMS_SIGNAL_1:
       puts( "ASR - rtems_task_wake_after - yield processor" );
+      FLUSH_OUTPUT();
       status = rtems_task_wake_after( RTEMS_YIELD_PROCESSOR );
       directive_failed( status, "rtems_task_wake_after yield" );
       break;
@@ -42,5 +44,6 @@ rtems_asr Process_asr(
       Asr_fired = TRUE;
       break;
   }
-  printf( "ASR - EXIT  - signal => %08x\n", the_signal_set );
+  printf( "ASR - EXIT  - signal => %08" PRIxrtems_signal_set "\n", the_signal_set );
+  FLUSH_OUTPUT();
 }
